%define libgpg_error_version 0
%define libgpg_error_fullversion 0.24.2
# The full version is significant as each new version may add symbols

%define name libgpg-error
%define version 1.31
%define release 1

# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 1}

# To use XLC : --define 'gcc_compiler=0'
%{!?gcc_compiler: %define gcc_compiler 1}
%{!?default_bits: %define default_bits 32}


%define _libdir64 %{_prefix}/lib64


Name:           %{name}
Version:        %{version}
Release:        %{release}
Summary:        A library defining common error values used by GnuPG components
Group:          System Environment/Libraries

License:        LGPLv2+
URL:            https://www.gnupg.org/related_software/libgpg-error/
Source0:        https://www.gnupg.org/ftp/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2
Source1:        https://www.gnupg.org/ftp/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2.sig

# RPM 3.0.5 does not recognize or initialise  %{buildroot} without following
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Prefix: %{_prefix}

Source10: %{name}-%{version}-%{release}.build.log

Patch1: libgpg-error-1.29-multilib.patch

BuildRequires:  gcc
BuildRequires: gettext, gettext-devel
# BuildRequires: texinfo
# BuildRequires: gettext-autopoint


%description
Libgpg-error is a library that defines common error values for all GnuPG
components. Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
Libksba, DirMngr, Pinentry, SCdaemon (SmartCard Daemon) and possibly more
in the future.

The library is available as 32-bit and 64-bit.

%if %{gcc_compiler} == 1
This version has been compiled with GCC.
%else
This version has been compiled with XLC.
%endif


%package devel
Summary: Development files for the %{name} package
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}


%description devel
Libgpg-error is a library that defines common error values for all GnuPG
components. Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
Libksba, DirMngr, Pinentry, SCdaemon (SmartCard Daemon) and possibly more
in the future.
This package contains files for application development using libgpg-error.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".

%if %{gcc_compiler} == 1
This version has been compiled with GCC.
%else
This version has been compiled with XLC.
%endif


%prep
%setup -q
%patch1 -p1 -b .multilib


echo "dotests=%{dotests}"
echo "default_bits=%{default_bits}"
echo "gcc_compiler=%{gcc_compiler}"
%if %{gcc_compiler} == 1
echo "GCC version=`/opt/freeware/bin/gcc --version | head -1`"
%endif



# Duplicate source for 32 & 64 bits
rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit



%build

/usr/bin/env | /usr/bin/sort

# setup environment for 32-bit and 64-bit builds
export AR="/usr/bin/ar -X32_64"
export RM="/usr/bin/rm -f"

# Choose XLC or GCC
%if %{gcc_compiler} == 1

export NM="/opt/freeware/bin/nm"
export CC__="/opt/freeware/bin/gcc"
export FLAG32="-maix32"
export FLAG64="-maix64"

echo "CC Version:"
$CC__ --version

%else

export NM="/usr/bin/nm -X32_64"
export CC__="xlc_r"
export FLAG32="-q32"
export FLAG64="-q64"

echo "CC Version:"
$CC__ -qversion

%endif

type $CC__

export CC32=" ${CC__}  ${FLAG32} -D_LARGE_FILES"
export CC64=" ${CC__}  ${FLAG64} -D_LARGE_FILES"


# First build the 64-bit version
cd 64bit
export OBJECT_MODE=64
export CC="${CC64}   $GLOBAL_CC_OPTIONS"

./configure -v --prefix=%{_prefix} \
               --infodir=%{_infodir} \
               --localedir=%{_datadir}/locale \
               --mandir=%{_mandir} \
               --disable-static \
               --disable-rpath \
               --disable-languages

gmake %{?_smp_mflags}



# Build the 32-bit version
cd ../32bit
export OBJECT_MODE=32
export CC="${CC32}   $GLOBAL_CC_OPTIONS"
export LDFLAGS=" -Wl,-bmaxdata:0x80000000"

./configure -v --prefix=%{_prefix} \
               --infodir=%{_infodir} \
               --localedir=%{_datadir}/locale \
               --mandir=%{_mandir} \
               --disable-static \
               --disable-rpath \
               --disable-languages

gmake %{?_smp_mflags}



# Archive 64 bit shared object in 32 bit shared library

slibclean
${AR} -q src/.libs/libgpg-error.a ../64bit/src/.libs/libgpg-error.so.%{libgpg_error_version}

slibclean

strip -e -X32_64     src/.libs/libgpg-error.so.%{libgpg_error_version} ../64bit/src/.libs/libgpg-error.so.%{libgpg_error_version}





%install

[ -d "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

export AR="/usr/bin/ar -X32_64"
# export RM="/usr/bin/rm -f"

cd 64bit
export OBJECT_MODE=64

gmake install DESTDIR="$RPM_BUILD_ROOT"


# Add libgpg-error.so.0 and libgpg-error.so & .so.0.24.2 - they may be required
mkdir    ${RPM_BUILD_ROOT}%{_libdir64}
install -p src/.libs/libgpg-error.so.%{libgpg_error_version} ${RPM_BUILD_ROOT}%{_libdir64}/libgpg-error.so.%{libgpg_error_version}
ln -sf  libgpg-error.so.%{libgpg_error_version}     ${RPM_BUILD_ROOT}%{_libdir64}/libgpg-error.so
ln -sf  libgpg-error.so.%{libgpg_error_version}     ${RPM_BUILD_ROOT}%{_libdir64}/libgpg-error.so.%{libgpg_error_fullversion}

# Following not required, as lib64/libgpg-error.a is symlink to lib/libgpg-error.a
# mv ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.a ${RPM_BUILD_ROOT}%{_libdir64}/libgpg-error.a


# %check is not recogized by RPM 3.0.5
#%check


# Currently there are 8 tests
if [ "%{dotests}" == 1 ]
then
  (gmake check || true)
fi

rm "$RPM_BUILD_ROOT%{_libdir}"/*.la

# Move lib to lib64
mv  ${RPM_BUILD_ROOT}/%{_libdir}  ${RPM_BUILD_ROOT}/%{_libdir64}

cd ../32bit
export OBJECT_MODE=32

gmake install DESTDIR="$RPM_BUILD_ROOT"


# Add libgpg-error.so.0 and libgpg-error.so & .so.0.24.2 - they may be required
install -p src/.libs/libgpg-error.so.%{libgpg_error_version} ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.so.%{libgpg_error_version}
ln -sf  libgpg-error.so.%{libgpg_error_version}     ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.so
ln -sf  libgpg-error.so.%{libgpg_error_version}     ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.so.%{libgpg_error_fullversion}

# Following is done in case a future version is incompatible
mv    ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.a ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error-%{libgpg_error_fullversion}.a
ln -s libgpg-error-%{libgpg_error_fullversion}.a ${RPM_BUILD_ROOT}%{_libdir}/libgpg-error.a
ln -s ../lib/libgpg-error.a ${RPM_BUILD_ROOT}%{_libdir64}/libgpg-error.a


# Currently there are 8 tests
if [ "%{dotests}" == 1 ]
then
  (gmake check || true)
fi

# rm "$RPM_BUILD_ROOT%{_libdir}"/*.la

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)




%files
%doc 32bit/COPYING 32bit/COPYING.LIB
%doc 32bit/AUTHORS 32bit/README 32bit/NEWS 32bit/ChangeLog
%{_bindir}/gpg-error
%{_libdir}/libgpg-error.a
%{_libdir}/libgpg-error-%{libgpg_error_fullversion}.a
%{_libdir64}/libgpg-error.a
%{_libdir}/libgpg-error.so.0*
%{_libdir64}/libgpg-error.so.0*
%{_datadir}/libgpg-error
%{_datadir}/locale
/usr/bin/gpg-error
/usr/lib/*.a


%files devel
%{_bindir}/gpg-error-config
%{_bindir}/gpgrt-config
%{_bindir}/yat2m
%{_libdir}/libgpg-error.so
%{_libdir64}/libgpg-error.so
%{_libdir}/*.la
%{_includedir}/gpg-error.h
%{_includedir}/gpgrt.h
%{_datadir}/aclocal/gpg-error.m4
%{_datadir}/aclocal/gpgrt.m4
%{_infodir}/gpgrt.info*
%{_mandir}/man1/gpg-error-config.*
/usr/bin/gpg-error-config
/usr/bin/gpgrt-config
/usr/bin/yat2m
/usr/include/gpg-error.h
/usr/include/gpgrt.h
/usr/lib/*.la



%changelog
* Thu Sep 27 2018 Michael Wilson <michael.a.wilson@atos.com> - 1.31-1
- Update to version 1.31 inspired by Fedora

* Wed Nov 08 2017 Tony Reix <tony.reix@atos.net> - 1.27-1
- Re-port
-
- Based on Thu Jul 13 2017 Michael Perzl <michael@perzl.org> - 1.27-1

* Tue Jul 03 2012 Gerard Visiedo <gerard.visiedo@bull.net> - 1.10-3
- Initial port on Aix6.1

* Thu Oct 13 2011 Gerard Visiedo <gerard.visiedo@bull.net> - 1.10-2
- rebuild for compatibility with new libiconv.a 1.13.1-2

* Wed Jun 15 2011 Gerard Visiedo <gerard.visiedo@bull.net>  1.10-1
- Initial port on Aix5.3

